# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/interface.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import types_pb2 as flyteidl_dot_core_dot_types__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import artifact_id_pb2 as flyteidl_dot_core_dot_artifact__id__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x66lyteidl/core/interface.proto\x12\rflyteidl.core\x1a\x19\x66lyteidl/core/types.proto\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x1f\x66lyteidl/core/artifact_id.proto\"\xe6\x01\n\x08Variable\x12.\n\x04type\x18\x01 \x01(\x0b\x32\x1a.flyteidl.core.LiteralTypeR\x04type\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12I\n\x13\x61rtifact_partial_id\x18\x03 \x01(\x0b\x32\x19.flyteidl.core.ArtifactIDR\x11\x61rtifactPartialId\x12=\n\x0c\x61rtifact_tag\x18\x04 \x01(\x0b\x32\x1a.flyteidl.core.ArtifactTagR\x0b\x61rtifactTag\"\xad\x01\n\x0bVariableMap\x12G\n\tvariables\x18\x01 \x03(\x0b\x32).flyteidl.core.VariableMap.VariablesEntryR\tvariables\x1aU\n\x0eVariablesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.flyteidl.core.VariableR\x05value:\x02\x38\x01\"z\n\x0eTypedInterface\x12\x32\n\x06inputs\x18\x01 \x01(\x0b\x32\x1a.flyteidl.core.VariableMapR\x06inputs\x12\x34\n\x07outputs\x18\x02 \x01(\x0b\x32\x1a.flyteidl.core.VariableMapR\x07outputs\"\x99\x02\n\tParameter\x12)\n\x03var\x18\x01 \x01(\x0b\x32\x17.flyteidl.core.VariableR\x03var\x12\x32\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32\x16.flyteidl.core.LiteralH\x00R\x07\x64\x65\x66\x61ult\x12\x1c\n\x08required\x18\x03 \x01(\x08H\x00R\x08required\x12\x45\n\x0e\x61rtifact_query\x18\x04 \x01(\x0b\x32\x1c.flyteidl.core.ArtifactQueryH\x00R\rartifactQuery\x12<\n\x0b\x61rtifact_id\x18\x05 \x01(\x0b\x32\x19.flyteidl.core.ArtifactIDH\x00R\nartifactIdB\n\n\x08\x62\x65havior\"\xb4\x01\n\x0cParameterMap\x12K\n\nparameters\x18\x01 \x03(\x0b\x32+.flyteidl.core.ParameterMap.ParametersEntryR\nparameters\x1aW\n\x0fParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x18.flyteidl.core.ParameterR\x05value:\x02\x38\x01\x42\xb4\x01\n\x11\x63om.flyteidl.coreB\x0eInterfaceProtoP\x01Z:github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/core\xa2\x02\x03\x46\x43X\xaa\x02\rFlyteidl.Core\xca\x02\rFlyteidl\\Core\xe2\x02\x19\x46lyteidl\\Core\\GPBMetadata\xea\x02\x0e\x46lyteidl::Coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.core.interface_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.flyteidl.coreB\016InterfaceProtoP\001Z:github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/core\242\002\003FCX\252\002\rFlyteidl.Core\312\002\rFlyteidl\\Core\342\002\031Flyteidl\\Core\\GPBMetadata\352\002\016Flyteidl::Core'
  _VARIABLEMAP_VARIABLESENTRY._options = None
  _VARIABLEMAP_VARIABLESENTRY._serialized_options = b'8\001'
  _PARAMETERMAP_PARAMETERSENTRY._options = None
  _PARAMETERMAP_PARAMETERSENTRY._serialized_options = b'8\001'
  _globals['_VARIABLE']._serialized_start=139
  _globals['_VARIABLE']._serialized_end=369
  _globals['_VARIABLEMAP']._serialized_start=372
  _globals['_VARIABLEMAP']._serialized_end=545
  _globals['_VARIABLEMAP_VARIABLESENTRY']._serialized_start=460
  _globals['_VARIABLEMAP_VARIABLESENTRY']._serialized_end=545
  _globals['_TYPEDINTERFACE']._serialized_start=547
  _globals['_TYPEDINTERFACE']._serialized_end=669
  _globals['_PARAMETER']._serialized_start=672
  _globals['_PARAMETER']._serialized_end=953
  _globals['_PARAMETERMAP']._serialized_start=956
  _globals['_PARAMETERMAP']._serialized_end=1136
  _globals['_PARAMETERMAP_PARAMETERSENTRY']._serialized_start=1049
  _globals['_PARAMETERMAP_PARAMETERSENTRY']._serialized_end=1136
# @@protoc_insertion_point(module_scope)
