# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x66lyteidl/service/auth.proto\x12\x10\x66lyteidl.service\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x17\n\x15OAuth2MetadataRequest\"\xa1\x04\n\x16OAuth2MetadataResponse\x12\x16\n\x06issuer\x18\x01 \x01(\tR\x06issuer\x12\x35\n\x16\x61uthorization_endpoint\x18\x02 \x01(\tR\x15\x61uthorizationEndpoint\x12%\n\x0etoken_endpoint\x18\x03 \x01(\tR\rtokenEndpoint\x12\x38\n\x18response_types_supported\x18\x04 \x03(\tR\x16responseTypesSupported\x12)\n\x10scopes_supported\x18\x05 \x03(\tR\x0fscopesSupported\x12P\n%token_endpoint_auth_methods_supported\x18\x06 \x03(\tR!tokenEndpointAuthMethodsSupported\x12\x19\n\x08jwks_uri\x18\x07 \x01(\tR\x07jwksUri\x12G\n code_challenge_methods_supported\x18\x08 \x03(\tR\x1d\x63odeChallengeMethodsSupported\x12\x32\n\x15grant_types_supported\x18\t \x03(\tR\x13grantTypesSupported\x12\x42\n\x1d\x64\x65vice_authorization_endpoint\x18\n \x01(\tR\x1b\x64\x65viceAuthorizationEndpoint\"\x1f\n\x1dPublicClientAuthConfigRequest\"\x86\x02\n\x1ePublicClientAuthConfigResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12!\n\x0credirect_uri\x18\x02 \x01(\tR\x0bredirectUri\x12\x16\n\x06scopes\x18\x03 \x03(\tR\x06scopes\x12<\n\x1a\x61uthorization_metadata_key\x18\x04 \x01(\tR\x18\x61uthorizationMetadataKey\x12\x32\n\x15service_http_endpoint\x18\x05 \x01(\tR\x13serviceHttpEndpoint\x12\x1a\n\x08\x61udience\x18\x06 \x01(\tR\x08\x61udience2\xfc\x03\n\x13\x41uthMetadataService\x12\xf5\x01\n\x11GetOAuth2Metadata\x12\'.flyteidl.service.OAuth2MetadataRequest\x1a(.flyteidl.service.OAuth2MetadataResponse\"\x8c\x01\x92\x41Z\x1aXRetrieves OAuth2 authorization server metadata. This endpoint is anonymously accessible.\x82\xd3\xe4\x93\x02)\x12\'/.well-known/oauth-authorization-server\x12\xec\x01\n\x15GetPublicClientConfig\x12/.flyteidl.service.PublicClientAuthConfigRequest\x1a\x30.flyteidl.service.PublicClientAuthConfigResponse\"p\x92\x41N\x1aLRetrieves public flyte client info. This endpoint is anonymously accessible.\x82\xd3\xe4\x93\x02\x19\x12\x17/config/v1/flyte_clientB\xc1\x01\n\x14\x63om.flyteidl.serviceB\tAuthProtoP\x01Z=github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/service\xa2\x02\x03\x46SX\xaa\x02\x10\x46lyteidl.Service\xca\x02\x10\x46lyteidl\\Service\xe2\x02\x1c\x46lyteidl\\Service\\GPBMetadata\xea\x02\x11\x46lyteidl::Serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.service.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.flyteidl.serviceB\tAuthProtoP\001Z=github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/service\242\002\003FSX\252\002\020Flyteidl.Service\312\002\020Flyteidl\\Service\342\002\034Flyteidl\\Service\\GPBMetadata\352\002\021Flyteidl::Service'
  _AUTHMETADATASERVICE.methods_by_name['GetOAuth2Metadata']._options = None
  _AUTHMETADATASERVICE.methods_by_name['GetOAuth2Metadata']._serialized_options = b'\222AZ\032XRetrieves OAuth2 authorization server metadata. This endpoint is anonymously accessible.\202\323\344\223\002)\022\'/.well-known/oauth-authorization-server'
  _AUTHMETADATASERVICE.methods_by_name['GetPublicClientConfig']._options = None
  _AUTHMETADATASERVICE.methods_by_name['GetPublicClientConfig']._serialized_options = b'\222AN\032LRetrieves public flyte client info. This endpoint is anonymously accessible.\202\323\344\223\002\031\022\027/config/v1/flyte_client'
  _globals['_OAUTH2METADATAREQUEST']._serialized_start=127
  _globals['_OAUTH2METADATAREQUEST']._serialized_end=150
  _globals['_OAUTH2METADATARESPONSE']._serialized_start=153
  _globals['_OAUTH2METADATARESPONSE']._serialized_end=698
  _globals['_PUBLICCLIENTAUTHCONFIGREQUEST']._serialized_start=700
  _globals['_PUBLICCLIENTAUTHCONFIGREQUEST']._serialized_end=731
  _globals['_PUBLICCLIENTAUTHCONFIGRESPONSE']._serialized_start=734
  _globals['_PUBLICCLIENTAUTHCONFIGRESPONSE']._serialized_end=996
  _globals['_AUTHMETADATASERVICE']._serialized_start=999
  _globals['_AUTHMETADATASERVICE']._serialized_end=1507
# @@protoc_insertion_point(module_scope)
