from google.api import annotations_pb2 as _annotations_pb2
from flyteidl.admin import signal_pb2 as _signal_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
