# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.event import event_pb2 as flyteidl_dot_event_dot_event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x66lyteidl/admin/event.proto\x12\x0e\x66lyteidl.admin\x1a\x1a\x66lyteidl/event/event.proto\"G\n EventErrorAlreadyInTerminalState\x12#\n\rcurrent_phase\x18\x01 \x01(\tR\x0c\x63urrentPhase\"9\n\x1d\x45ventErrorIncompatibleCluster\x12\x18\n\x07\x63luster\x18\x01 \x01(\tR\x07\x63luster\"\xf1\x01\n\x12\x45ventFailureReason\x12m\n\x19\x61lready_in_terminal_state\x18\x01 \x01(\x0b\x32\x30.flyteidl.admin.EventErrorAlreadyInTerminalStateH\x00R\x16\x61lreadyInTerminalState\x12\x62\n\x14incompatible_cluster\x18\x02 \x01(\x0b\x32-.flyteidl.admin.EventErrorIncompatibleClusterH\x00R\x13incompatibleClusterB\x08\n\x06reason\"|\n\x1dWorkflowExecutionEventRequest\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12<\n\x05\x65vent\x18\x02 \x01(\x0b\x32&.flyteidl.event.WorkflowExecutionEventR\x05\x65vent\" \n\x1eWorkflowExecutionEventResponse\"t\n\x19NodeExecutionEventRequest\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\x38\n\x05\x65vent\x18\x02 \x01(\x0b\x32\".flyteidl.event.NodeExecutionEventR\x05\x65vent\"\x1c\n\x1aNodeExecutionEventResponse\"t\n\x19TaskExecutionEventRequest\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\x38\n\x05\x65vent\x18\x02 \x01(\x0b\x32\".flyteidl.event.TaskExecutionEventR\x05\x65vent\"\x1c\n\x1aTaskExecutionEventResponseB\xb6\x01\n\x12\x63om.flyteidl.adminB\nEventProtoP\x01Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/admin\xa2\x02\x03\x46\x41X\xaa\x02\x0e\x46lyteidl.Admin\xca\x02\x0e\x46lyteidl\\Admin\xe2\x02\x1a\x46lyteidl\\Admin\\GPBMetadata\xea\x02\x0f\x46lyteidl::Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.admin.event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.flyteidl.adminB\nEventProtoP\001Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/admin\242\002\003FAX\252\002\016Flyteidl.Admin\312\002\016Flyteidl\\Admin\342\002\032Flyteidl\\Admin\\GPBMetadata\352\002\017Flyteidl::Admin'
  _globals['_EVENTERRORALREADYINTERMINALSTATE']._serialized_start=74
  _globals['_EVENTERRORALREADYINTERMINALSTATE']._serialized_end=145
  _globals['_EVENTERRORINCOMPATIBLECLUSTER']._serialized_start=147
  _globals['_EVENTERRORINCOMPATIBLECLUSTER']._serialized_end=204
  _globals['_EVENTFAILUREREASON']._serialized_start=207
  _globals['_EVENTFAILUREREASON']._serialized_end=448
  _globals['_WORKFLOWEXECUTIONEVENTREQUEST']._serialized_start=450
  _globals['_WORKFLOWEXECUTIONEVENTREQUEST']._serialized_end=574
  _globals['_WORKFLOWEXECUTIONEVENTRESPONSE']._serialized_start=576
  _globals['_WORKFLOWEXECUTIONEVENTRESPONSE']._serialized_end=608
  _globals['_NODEEXECUTIONEVENTREQUEST']._serialized_start=610
  _globals['_NODEEXECUTIONEVENTREQUEST']._serialized_end=726
  _globals['_NODEEXECUTIONEVENTRESPONSE']._serialized_start=728
  _globals['_NODEEXECUTIONEVENTRESPONSE']._serialized_end=756
  _globals['_TASKEXECUTIONEVENTREQUEST']._serialized_start=758
  _globals['_TASKEXECUTIONEVENTREQUEST']._serialized_end=874
  _globals['_TASKEXECUTIONEVENTRESPONSE']._serialized_start=876
  _globals['_TASKEXECUTIONEVENTRESPONSE']._serialized_end=904
# @@protoc_insertion_point(module_scope)
